@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
+/* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 #include "../include/Win_GParted.h"
 #include "../include/GParted_Core.h"
 #include "../include/DMRaid.h"
+#include "../include/SWRaid.h"
 #include "../include/FS_Info.h"
 #include "../include/OperationCopy.h"
 #include "../include/OperationCreate.h"
@@ -160,6 +162,7 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 	Device temp_device ;
 	FS_Info fs_info( true ) ;  //Refresh cache of file system information
 	DMRaid dmraid( true ) ;    //Refresh cache of dmraid device information
+	SWRaid swraid( true ) ;    //Refresh cache of swraid device information
 	
 	init_maps() ;
 	
@@ -204,6 +207,16 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 			}
 			proc_partitions .close() ;
 
+			//Try to find all swraid devices
+			if (swraid .is_swraid_supported() ) {
+				std::vector<Glib::ustring> swraid_devices ;
+				swraid .get_devices( swraid_devices ) ;
+				for ( unsigned int k=0; k < swraid_devices .size(); k++ ) {
+					set_thread_status_message( String::ucompose ( _("Scanning %1"), swraid_devices[k] ) ) ;
+					ped_device_get( swraid_devices[k] .c_str() ) ;
+				}
+			}
+
 			//Try to find all dmraid devices
 			if (dmraid .is_dmraid_supported() ) {
 				std::vector<Glib::ustring> dmraid_devices ;
@@ -295,7 +308,12 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 				set_used_sectors( temp_device .partitions ) ;
 			
 				if ( temp_device .highest_busy )
+				{
 					temp_device .readonly = ! commit_to_os( 1 ) ;
+					//Clear libparted messages.  Typically these are:
+					//  The kernel was unable to re-read the partition table...
+					libparted_messages .clear() ;
+				}
 			}
 			//harddisk without disklabel
 			else
@@ -308,6 +326,11 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 								 0,
 								 temp_device .length,
 								 false );
+				//Place libparted messages in this unallocated partition
+				partition_temp .messages .insert( partition_temp .messages .end(),
+								  libparted_messages. begin(),
+								  libparted_messages .end() ) ;
+				libparted_messages .clear() ;
 				temp_device .partitions .push_back( partition_temp );
 			}
 					
@@ -2726,8 +2749,8 @@ void GParted_Core::close_device_and_disk()
 bool GParted_Core::commit() 
 {
 	bool succes = ped_disk_commit_to_dev( lp_disk ) ;
-	
-	commit_to_os( 10 ) ;
+
+	succes = commit_to_os( 10 ) && succes ;
 
 	return succes ;
 }
