@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,7 +49,7 @@ FS ntfs::get_filesystem_support()
 		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = GParted::FS::EXTERNAL ;
 	}
-	
+
 	//we need ntfsresize to set correct used/unused after cloning
 	if ( ! Glib::find_program_in_path( "ntfsclone" ) .empty() )
 		fs .copy = GParted::FS::EXTERNAL ;
@@ -105,13 +106,13 @@ bool ntfs::write_label( const Partition & partition, OperationDetail & operation
 
 bool ntfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkntfs -Q -vv -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkntfs -Q -v -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
 }
 
 bool ntfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool return_value = false ;
-	Glib::ustring str_temp = "ntfsresize -P --force --force " + partition_new .get_path() ;
+	Glib::ustring str_temp = "ntfsresize -P --force " + partition_new .get_path() ;
 	
 	if ( ! fill_partition )
 	{
